@@ -1,11 +1,11 @@
 package Test::Class::Module::Build::Bundle;
 
-# $Id: Bundle.pm 7978 2012-11-24 08:13:41Z jonasbn $
+# $Id: Bundle.pm 7622 2011-04-23 11:39:22Z jonasbn $
 
 use strict;
 use warnings;
 use Test::More;
-use Module::Build::YAML;
+use CPAN::Meta::YAML;
 use Test::MockObject::Extends;
 use FindBin;
 use lib "$FindBin::Bin/../t";
@@ -15,7 +15,7 @@ use base qw(Test::Class);
 sub startup : Test(startup) {
     my $test = shift;
     
-    my $yaml = Module::Build::YAML->new();
+    my $yaml = CPAN::Meta::YAML->new();
     
     $test->{yaml} = $yaml;
 }
